# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: v1.11.2
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1EventSeries(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'int',
        'last_observed_time': 'datetime',
        'state': 'str'
    }

    attribute_map = {
        'count': 'count',
        'last_observed_time': 'lastObservedTime',
        'state': 'state'
    }

    def __init__(self, count=None, last_observed_time=None, state=None):
        """
        V1EventSeries - a model defined in Swagger
        """

        self._count = None
        self._last_observed_time = None
        self._state = None
        self.discriminator = None

        if count is not None:
          self.count = count
        if last_observed_time is not None:
          self.last_observed_time = last_observed_time
        if state is not None:
          self.state = state

    @property
    def count(self):
        """
        Gets the count of this V1EventSeries.
        Number of occurrences in this series up to the last heartbeat time

        :return: The count of this V1EventSeries.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this V1EventSeries.
        Number of occurrences in this series up to the last heartbeat time

        :param count: The count of this V1EventSeries.
        :type: int
        """

        self._count = count

    @property
    def last_observed_time(self):
        """
        Gets the last_observed_time of this V1EventSeries.
        Time of the last occurrence observed

        :return: The last_observed_time of this V1EventSeries.
        :rtype: datetime
        """
        return self._last_observed_time

    @last_observed_time.setter
    def last_observed_time(self, last_observed_time):
        """
        Sets the last_observed_time of this V1EventSeries.
        Time of the last occurrence observed

        :param last_observed_time: The last_observed_time of this V1EventSeries.
        :type: datetime
        """

        self._last_observed_time = last_observed_time

    @property
    def state(self):
        """
        Gets the state of this V1EventSeries.
        State of this Series: Ongoing or Finished

        :return: The state of this V1EventSeries.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this V1EventSeries.
        State of this Series: Ongoing or Finished

        :param state: The state of this V1EventSeries.
        :type: str
        """

        self._state = state

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1EventSeries):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
